@@ -99,7 +99,7 @@ def test_vqe_layer(tfb, highp):
 
     model.fit(np.zeros([2, 1]), np.zeros([2, 1]), batch_size=2, epochs=500)
 
-    assert np.allclose(model.predict(np.zeros([1])), -7.27, atol=5e-2)
+    np.testing.assert_allclose(model.predict(np.zeros([1])), -7.27, atol=5e-2)
 
 
 def test_function_io(tfb, tmp_path, highp):
